@@ -1,8 +1,8 @@
 var searchData=
 [
   ['d_0',['d',['../structDav1dSegmentationDataSet.html#a9a5f7c927df14d61f15d06cb0d359f09',1,'Dav1dSegmentationDataSet']]],
-  ['damping_1',['damping',['../structDav1dFrameHeader.html#a367442febb62bbcc539c17f473bda63b',1,'Dav1dFrameHeader']]],
-  ['data_2',['data',['../structDav1dPicture.html#ae6a2b8538d7a43aaab3f46d2198e67fa',1,'Dav1dPicture::data'],['../structDav1dFrameHeader.html#a0793ad1ee6079e66307a11c3b3bb6432',1,'Dav1dFrameHeader::data'],['../structDav1dData.html#a08e47b7276c43111369e43439f8cfe9f',1,'Dav1dData::data'],['../structDav1dUserData.html#abea83576f25527ba0b464d28e86f2757',1,'Dav1dUserData::data']]],
+  ['damping_1',['damping',['../structDav1dFrameHeader.html#af7f944a1a64aa605447ed26f1ed30463',1,'Dav1dFrameHeader']]],
+  ['data_2',['data',['../structDav1dUserData.html#abea83576f25527ba0b464d28e86f2757',1,'Dav1dUserData::data'],['../structDav1dData.html#a08e47b7276c43111369e43439f8cfe9f',1,'Dav1dData::data'],['../structDav1dFrameHeader.html#a0793ad1ee6079e66307a11c3b3bb6432',1,'Dav1dFrameHeader::data'],['../structDav1dPicture.html#ae6a2b8538d7a43aaab3f46d2198e67fa',1,'Dav1dPicture::data']]],
   ['data_2eh_3',['data.h',['../data_8h.html',1,'']]],
   ['dav1d_2eh_4',['dav1d.h',['../dav1d_8h.html',1,'']]],
   ['dav1d_5fadaptive_5',['DAV1D_ADAPTIVE',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5a66e6af92cf2d442f04a1dd7cab7e2a02',1,'headers.h']]],
@@ -131,62 +131,63 @@ var searchData=
   ['dav1d_5ftx_5flargest_128',['DAV1D_TX_LARGEST',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8a76279b87af8c7fb1b8c586acf90dae4c',1,'headers.h']]],
   ['dav1d_5ftx_5fswitchable_129',['DAV1D_TX_SWITCHABLE',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8adc6182d0aae1bd4e1effff09d2fca74c',1,'headers.h']]],
   ['dav1d_5fversion_130',['dav1d_version',['../dav1d_8h.html#a9ec06f24b3798b1123dc7d3e468bbac4',1,'dav1d.h']]],
-  ['dav1d_5fwm_5ftype_5faffine_131',['DAV1D_WM_TYPE_AFFINE',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97a6d12578cc1105b97989eadacf5cd67dc',1,'headers.h']]],
-  ['dav1d_5fwm_5ftype_5fidentity_132',['DAV1D_WM_TYPE_IDENTITY',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97a24db5aa662a1365b33d4f2ebc1bec9f9',1,'headers.h']]],
-  ['dav1d_5fwm_5ftype_5frot_5fzoom_133',['DAV1D_WM_TYPE_ROT_ZOOM',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97afb1a4a46bbd3239fda49e7f0adc6cbe5',1,'headers.h']]],
-  ['dav1d_5fwm_5ftype_5ftranslation_134',['DAV1D_WM_TYPE_TRANSLATION',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97ae6b2d94797bf270106ccb4390ecc6c1a',1,'headers.h']]],
-  ['dav1dadaptiveboolean_135',['Dav1dAdaptiveBoolean',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5',1,'headers.h']]],
-  ['dav1dchromasampleposition_136',['Dav1dChromaSamplePosition',['../headers_8h.html#a400522daeb5177ba86ee9da1960bd828',1,'headers.h']]],
-  ['dav1dcolorprimaries_137',['Dav1dColorPrimaries',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522ba',1,'headers.h']]],
-  ['dav1dcontentlightlevel_138',['Dav1dContentLightLevel',['../structDav1dContentLightLevel.html',1,'']]],
-  ['dav1dcontext_139',['Dav1dContext',['../dav1d_8h.html#a7f3e646528835d5abcc352a1c0e20c31',1,'dav1d.h']]],
-  ['dav1ddata_140',['Dav1dData',['../structDav1dData.html',1,'']]],
-  ['dav1ddataprops_141',['Dav1dDataProps',['../structDav1dDataProps.html',1,'']]],
-  ['dav1ddecodeframetype_142',['Dav1dDecodeFrameType',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5',1,'dav1d.h']]],
-  ['dav1deventflags_143',['Dav1dEventFlags',['../dav1d_8h.html#a7df42645bae950bcf1ea0a10cf11126d',1,'dav1d.h']]],
-  ['dav1dfilmgraindata_144',['Dav1dFilmGrainData',['../structDav1dFilmGrainData.html',1,'']]],
-  ['dav1dfiltermode_145',['Dav1dFilterMode',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3dea',1,'headers.h']]],
-  ['dav1dframeheader_146',['Dav1dFrameHeader',['../structDav1dFrameHeader.html',1,'']]],
-  ['dav1dframeheaderoperatingpoint_147',['Dav1dFrameHeaderOperatingPoint',['../structDav1dFrameHeader_1_1Dav1dFrameHeaderOperatingPoint.html',1,'Dav1dFrameHeader']]],
-  ['dav1dframetype_148',['Dav1dFrameType',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893',1,'headers.h']]],
-  ['dav1dinloopfiltertype_149',['Dav1dInloopFilterType',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67',1,'dav1d.h']]],
-  ['dav1ditutt35_150',['Dav1dITUTT35',['../structDav1dITUTT35.html',1,'']]],
-  ['dav1dlogger_151',['Dav1dLogger',['../structDav1dLogger.html',1,'']]],
-  ['dav1dloopfiltermoderefdeltas_152',['Dav1dLoopfilterModeRefDeltas',['../structDav1dLoopfilterModeRefDeltas.html',1,'']]],
-  ['dav1dmasteringdisplay_153',['Dav1dMasteringDisplay',['../structDav1dMasteringDisplay.html',1,'']]],
-  ['dav1dmatrixcoefficients_154',['Dav1dMatrixCoefficients',['../headers_8h.html#ab615aa670362bc69fc4177e07585399b',1,'headers.h']]],
-  ['dav1dobutype_155',['Dav1dObuType',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2',1,'headers.h']]],
-  ['dav1dpicallocator_156',['Dav1dPicAllocator',['../structDav1dPicAllocator.html',1,'']]],
-  ['dav1dpicture_157',['Dav1dPicture',['../structDav1dPicture.html',1,'']]],
-  ['dav1dpictureparameters_158',['Dav1dPictureParameters',['../structDav1dPictureParameters.html',1,'']]],
-  ['dav1dpixellayout_159',['Dav1dPixelLayout',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7d',1,'headers.h']]],
-  ['dav1dref_160',['Dav1dRef',['../dav1d_8h.html#a5f3cad70d6c7586b658d1d25b0355840',1,'dav1d.h']]],
-  ['dav1drestorationtype_161',['Dav1dRestorationType',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301',1,'headers.h']]],
-  ['dav1dsegmentationdata_162',['Dav1dSegmentationData',['../structDav1dSegmentationData.html',1,'']]],
-  ['dav1dsegmentationdataset_163',['Dav1dSegmentationDataSet',['../structDav1dSegmentationDataSet.html',1,'']]],
-  ['dav1dsequenceheader_164',['Dav1dSequenceHeader',['../structDav1dSequenceHeader.html',1,'']]],
-  ['dav1dsequenceheaderoperatingparameterinfo_165',['Dav1dSequenceHeaderOperatingParameterInfo',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html',1,'Dav1dSequenceHeader']]],
-  ['dav1dsequenceheaderoperatingpoint_166',['Dav1dSequenceHeaderOperatingPoint',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html',1,'Dav1dSequenceHeader']]],
-  ['dav1dsettings_167',['Dav1dSettings',['../structDav1dSettings.html',1,'']]],
-  ['dav1dtransfercharacteristics_168',['Dav1dTransferCharacteristics',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4e',1,'headers.h']]],
-  ['dav1dtxfmmode_169',['Dav1dTxfmMode',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8',1,'headers.h']]],
-  ['dav1duserdata_170',['Dav1dUserData',['../structDav1dUserData.html',1,'']]],
-  ['dav1dwarpedmotionparams_171',['Dav1dWarpedMotionParams',['../structDav1dWarpedMotionParams.html',1,'']]],
-  ['dav1dwarpedmotiontype_172',['Dav1dWarpedMotionType',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97',1,'headers.h']]],
-  ['decode_5fframe_5ftype_173',['decode_frame_type',['../structDav1dSettings.html#a54a22d80474a060f5e92a3f858780f23',1,'Dav1dSettings']]],
-  ['decoder_5fbuffer_5fdelay_174',['decoder_buffer_delay',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html#af793e75b7698824189eb9fb506e3ba91',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingParameterInfo']]],
-  ['decoder_5fmodel_5finfo_5fpresent_175',['decoder_model_info_present',['../structDav1dSequenceHeader.html#a6bab00a018e0a1ffb7c01eca7cd2e1d6',1,'Dav1dSequenceHeader']]],
-  ['decoder_5fmodel_5fparam_5fpresent_176',['decoder_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a4c798f7eb4166a61cbcd3149b5553ddc',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
-  ['delta_177',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta']]],
-  ['delta_5fframe_5fid_5fn_5fbits_178',['delta_frame_id_n_bits',['../structDav1dSequenceHeader.html#ac9e01409b43b5ec65ae98c911234ce40',1,'Dav1dSequenceHeader']]],
-  ['delta_5flf_5fu_179',['delta_lf_u',['../structDav1dSegmentationData.html#ae61b74492ae6ee1320d1663dd907e0ea',1,'Dav1dSegmentationData']]],
-  ['delta_5flf_5fv_180',['delta_lf_v',['../structDav1dSegmentationData.html#ac7f645e6d299541eb72829c007e01fc5',1,'Dav1dSegmentationData']]],
-  ['delta_5flf_5fy_5fh_181',['delta_lf_y_h',['../structDav1dSegmentationData.html#a7e41d6e7588adeee5cbf473694fde160',1,'Dav1dSegmentationData']]],
-  ['delta_5flf_5fy_5fv_182',['delta_lf_y_v',['../structDav1dSegmentationData.html#ac262acad78c2dfcd5310fda34c93bc55',1,'Dav1dSegmentationData']]],
-  ['delta_5fq_183',['delta_q',['../structDav1dSegmentationData.html#ae0445170e6ccd7f4dffdf97d443a00d4',1,'Dav1dSegmentationData']]],
-  ['disable_5fcdf_5fupdate_184',['disable_cdf_update',['../structDav1dFrameHeader.html#af5d6782a4043529a70bbd3a3c27c6560',1,'Dav1dFrameHeader']]],
-  ['display_5fmodel_5finfo_5fpresent_185',['display_model_info_present',['../structDav1dSequenceHeader.html#a0c6e87f5539cc5cdac0f157c0ba2725f',1,'Dav1dSequenceHeader']]],
-  ['display_5fmodel_5fparam_5fpresent_186',['display_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a2d86a6a9b3cadf3304901b1ef38a11f5',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
-  ['dual_5ffilter_187',['dual_filter',['../structDav1dSequenceHeader.html#a196eb28472b2a4b8387d47747160deb6',1,'Dav1dSequenceHeader']]],
-  ['duration_188',['duration',['../structDav1dDataProps.html#aedb99d78a3677949765aeeedb352e3ac',1,'Dav1dDataProps']]]
+  ['dav1d_5fversion_5fapi_131',['dav1d_version_api',['../dav1d_8h.html#ad2556dfaf946f4fa8dcd532be816c37d',1,'dav1d.h']]],
+  ['dav1d_5fwm_5ftype_5faffine_132',['DAV1D_WM_TYPE_AFFINE',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97a6d12578cc1105b97989eadacf5cd67dc',1,'headers.h']]],
+  ['dav1d_5fwm_5ftype_5fidentity_133',['DAV1D_WM_TYPE_IDENTITY',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97a24db5aa662a1365b33d4f2ebc1bec9f9',1,'headers.h']]],
+  ['dav1d_5fwm_5ftype_5frot_5fzoom_134',['DAV1D_WM_TYPE_ROT_ZOOM',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97afb1a4a46bbd3239fda49e7f0adc6cbe5',1,'headers.h']]],
+  ['dav1d_5fwm_5ftype_5ftranslation_135',['DAV1D_WM_TYPE_TRANSLATION',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97ae6b2d94797bf270106ccb4390ecc6c1a',1,'headers.h']]],
+  ['dav1dadaptiveboolean_136',['Dav1dAdaptiveBoolean',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5',1,'headers.h']]],
+  ['dav1dchromasampleposition_137',['Dav1dChromaSamplePosition',['../headers_8h.html#a400522daeb5177ba86ee9da1960bd828',1,'headers.h']]],
+  ['dav1dcolorprimaries_138',['Dav1dColorPrimaries',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522ba',1,'headers.h']]],
+  ['dav1dcontentlightlevel_139',['Dav1dContentLightLevel',['../structDav1dContentLightLevel.html',1,'']]],
+  ['dav1dcontext_140',['Dav1dContext',['../dav1d_8h.html#a7f3e646528835d5abcc352a1c0e20c31',1,'dav1d.h']]],
+  ['dav1ddata_141',['Dav1dData',['../structDav1dData.html',1,'']]],
+  ['dav1ddataprops_142',['Dav1dDataProps',['../structDav1dDataProps.html',1,'']]],
+  ['dav1ddecodeframetype_143',['Dav1dDecodeFrameType',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5',1,'dav1d.h']]],
+  ['dav1deventflags_144',['Dav1dEventFlags',['../dav1d_8h.html#a7df42645bae950bcf1ea0a10cf11126d',1,'dav1d.h']]],
+  ['dav1dfilmgraindata_145',['Dav1dFilmGrainData',['../structDav1dFilmGrainData.html',1,'']]],
+  ['dav1dfiltermode_146',['Dav1dFilterMode',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3dea',1,'headers.h']]],
+  ['dav1dframeheader_147',['Dav1dFrameHeader',['../structDav1dFrameHeader.html',1,'']]],
+  ['dav1dframeheaderoperatingpoint_148',['Dav1dFrameHeaderOperatingPoint',['../structDav1dFrameHeader_1_1Dav1dFrameHeaderOperatingPoint.html',1,'Dav1dFrameHeader']]],
+  ['dav1dframetype_149',['Dav1dFrameType',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893',1,'headers.h']]],
+  ['dav1dinloopfiltertype_150',['Dav1dInloopFilterType',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67',1,'dav1d.h']]],
+  ['dav1ditutt35_151',['Dav1dITUTT35',['../structDav1dITUTT35.html',1,'']]],
+  ['dav1dlogger_152',['Dav1dLogger',['../structDav1dLogger.html',1,'']]],
+  ['dav1dloopfiltermoderefdeltas_153',['Dav1dLoopfilterModeRefDeltas',['../structDav1dLoopfilterModeRefDeltas.html',1,'']]],
+  ['dav1dmasteringdisplay_154',['Dav1dMasteringDisplay',['../structDav1dMasteringDisplay.html',1,'']]],
+  ['dav1dmatrixcoefficients_155',['Dav1dMatrixCoefficients',['../headers_8h.html#ab615aa670362bc69fc4177e07585399b',1,'headers.h']]],
+  ['dav1dobutype_156',['Dav1dObuType',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2',1,'headers.h']]],
+  ['dav1dpicallocator_157',['Dav1dPicAllocator',['../structDav1dPicAllocator.html',1,'']]],
+  ['dav1dpicture_158',['Dav1dPicture',['../structDav1dPicture.html',1,'']]],
+  ['dav1dpictureparameters_159',['Dav1dPictureParameters',['../structDav1dPictureParameters.html',1,'']]],
+  ['dav1dpixellayout_160',['Dav1dPixelLayout',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7d',1,'headers.h']]],
+  ['dav1dref_161',['Dav1dRef',['../dav1d_8h.html#a5f3cad70d6c7586b658d1d25b0355840',1,'dav1d.h']]],
+  ['dav1drestorationtype_162',['Dav1dRestorationType',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301',1,'headers.h']]],
+  ['dav1dsegmentationdata_163',['Dav1dSegmentationData',['../structDav1dSegmentationData.html',1,'']]],
+  ['dav1dsegmentationdataset_164',['Dav1dSegmentationDataSet',['../structDav1dSegmentationDataSet.html',1,'']]],
+  ['dav1dsequenceheader_165',['Dav1dSequenceHeader',['../structDav1dSequenceHeader.html',1,'']]],
+  ['dav1dsequenceheaderoperatingparameterinfo_166',['Dav1dSequenceHeaderOperatingParameterInfo',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html',1,'Dav1dSequenceHeader']]],
+  ['dav1dsequenceheaderoperatingpoint_167',['Dav1dSequenceHeaderOperatingPoint',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html',1,'Dav1dSequenceHeader']]],
+  ['dav1dsettings_168',['Dav1dSettings',['../structDav1dSettings.html',1,'']]],
+  ['dav1dtransfercharacteristics_169',['Dav1dTransferCharacteristics',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4e',1,'headers.h']]],
+  ['dav1dtxfmmode_170',['Dav1dTxfmMode',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8',1,'headers.h']]],
+  ['dav1duserdata_171',['Dav1dUserData',['../structDav1dUserData.html',1,'']]],
+  ['dav1dwarpedmotionparams_172',['Dav1dWarpedMotionParams',['../structDav1dWarpedMotionParams.html',1,'']]],
+  ['dav1dwarpedmotiontype_173',['Dav1dWarpedMotionType',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97',1,'headers.h']]],
+  ['decode_5fframe_5ftype_174',['decode_frame_type',['../structDav1dSettings.html#a54a22d80474a060f5e92a3f858780f23',1,'Dav1dSettings']]],
+  ['decoder_5fbuffer_5fdelay_175',['decoder_buffer_delay',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html#a2174e702c154799ce1f113a83d9e60b5',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingParameterInfo']]],
+  ['decoder_5fmodel_5finfo_5fpresent_176',['decoder_model_info_present',['../structDav1dSequenceHeader.html#a547c4f413e7a2f6ca50f556ea659eef9',1,'Dav1dSequenceHeader']]],
+  ['decoder_5fmodel_5fparam_5fpresent_177',['decoder_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a0dcdf8ba72856b36911dce7b06f246fb',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
+  ['delta_178',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta']]],
+  ['delta_5fframe_5fid_5fn_5fbits_179',['delta_frame_id_n_bits',['../structDav1dSequenceHeader.html#a1e97efb39c4d53037161faed3cbf84ac',1,'Dav1dSequenceHeader']]],
+  ['delta_5flf_5fu_180',['delta_lf_u',['../structDav1dSegmentationData.html#a4de13df0c53def4d92c96d514782da6e',1,'Dav1dSegmentationData']]],
+  ['delta_5flf_5fv_181',['delta_lf_v',['../structDav1dSegmentationData.html#aa9cf9e0a5174f9fc8531013304e1d981',1,'Dav1dSegmentationData']]],
+  ['delta_5flf_5fy_5fh_182',['delta_lf_y_h',['../structDav1dSegmentationData.html#a72aece922c5726b270984521c6dc17ee',1,'Dav1dSegmentationData']]],
+  ['delta_5flf_5fy_5fv_183',['delta_lf_y_v',['../structDav1dSegmentationData.html#a6fbbe5378f59a6a5e5919b768271ce69',1,'Dav1dSegmentationData']]],
+  ['delta_5fq_184',['delta_q',['../structDav1dSegmentationData.html#acfbfd240f5951c814523c4da8fdbd588',1,'Dav1dSegmentationData']]],
+  ['disable_5fcdf_5fupdate_185',['disable_cdf_update',['../structDav1dFrameHeader.html#a129b2318f996385be46fe9981c17af79',1,'Dav1dFrameHeader']]],
+  ['display_5fmodel_5finfo_5fpresent_186',['display_model_info_present',['../structDav1dSequenceHeader.html#aef0be3e10de2185de486ce5420fe746a',1,'Dav1dSequenceHeader']]],
+  ['display_5fmodel_5fparam_5fpresent_187',['display_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a9778cf78a5530ece70c61cdec6869058',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
+  ['dual_5ffilter_188',['dual_filter',['../structDav1dSequenceHeader.html#aef6e1a913236b2f859966e3eb7367cd2',1,'Dav1dSequenceHeader']]],
+  ['duration_189',['duration',['../structDav1dDataProps.html#aedb99d78a3677949765aeeedb352e3ac',1,'Dav1dDataProps']]]
 ];
