@@ -7,7 +7,7 @@ var searchData=
   ['decoder_5fbuffer_5fdelay_4',['decoder_buffer_delay',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html#a2174e702c154799ce1f113a83d9e60b5',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingParameterInfo']]],
   ['decoder_5fmodel_5finfo_5fpresent_5',['decoder_model_info_present',['../structDav1dSequenceHeader.html#a547c4f413e7a2f6ca50f556ea659eef9',1,'Dav1dSequenceHeader']]],
   ['decoder_5fmodel_5fparam_5fpresent_6',['decoder_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a0dcdf8ba72856b36911dce7b06f246fb',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
-  ['delta_7',['delta',['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta'],['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta']]],
+  ['delta_7',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta']]],
   ['delta_5fframe_5fid_5fn_5fbits_8',['delta_frame_id_n_bits',['../structDav1dSequenceHeader.html#a1e97efb39c4d53037161faed3cbf84ac',1,'Dav1dSequenceHeader']]],
   ['delta_5flf_5fu_9',['delta_lf_u',['../structDav1dSegmentationData.html#a4de13df0c53def4d92c96d514782da6e',1,'Dav1dSegmentationData']]],
   ['delta_5flf_5fv_10',['delta_lf_v',['../structDav1dSegmentationData.html#aa9cf9e0a5174f9fc8531013304e1d981',1,'Dav1dSegmentationData']]],
